import { DebugProtocol } from 'vscode-debugprotocol';
import { FileFolderType, IFileInfo } from './api';
import { IMethodAttributes, ITextEditorSelection } from './code-editor';
import { IEditor } from './explorer';
export type DebuggerFileExtension = '4dm' | '4qs';
export interface ICodeDescriptor {
    type: number;
    methodName?: string;
    className?: string;
    functionName?: string;
    methodPath?: string;
}
export interface ISource extends DebugProtocol.Source {
    codeDescriptor?: ICodeDescriptor;
    codeDescriptorInfo?: ICodeDescriptor;
}
export type ITabFlags = Partial<{
    touched: boolean;
    removed: boolean;
    pinned: boolean;
    loading: boolean;
    old: boolean;
    enabled: boolean;
}>;
export interface IEditorTab<T = string> {
    path: string;
    type?: FileFolderType;
    content: T;
    extra?: ITabExtra;
    language?: string;
    theme?: string;
    name?: string;
}
export type ITabExtra = Partial<{
    initialLineInfo: {
        line: number;
        offset?: number;
        lastModification: number;
    };
    initialSelectionInfo: {
        selection: ITextEditorSelection;
        lastModification: number;
    };
    diffContent: string;
    attributes: IMethodAttributes;
    source: ISource;
    editor: IEditor;
    ext: DebuggerFileExtension;
}>;
export interface ITab<T = any, G = ITabExtra> extends IFileInfo {
    content?: T;
    weight?: number;
    prefix?: string;
    extra?: G;
    view: {
        panel: {
            isOpen: boolean;
            type: string;
            current: string;
        };
    };
    flags: ITabFlags;
    initialContent?: T;
}
export type WebformTab = ITab<webforms.Content>;
export interface IAppState {
    files: IFileInfo[];
    tabs: ITab[];
    activeTab: string;
}
export declare enum ERROR_CODES {
    FILE_NOT_FOUND = 1839,
    JSON_MALFORMED = 554,
    JSON_MALFORMED_AT_LINE = 550
}
export interface GetNodeInfoException {
    data: {
        __ERROR: [
            {
                errCode: number;
            }
        ];
    };
}
